<template>
    <div class="home-container">
        <div style="height: 100%">
            <el-row class="homeCard">
                <el-col :span="8">
                    <div class="grid-content topInfo">
                        <el-input v-model="searchWord" placeholder="流程名称"></el-input>
                        <el-button type="primary">查询</el-button>
                        <el-button plain>重置</el-button>
                    </div>
                </el-col>
            </el-row>
            <div class="homeCard">
                <div class="main-card">
                    <el-row class="cardTop">
                        <el-col :span="12" class="mainCardBtn">
                            <el-button type="primary" :icon="Plus" size="default" @click="dialogAddRecord = true" v-throttle>新建</el-button>
                            <el-button type="danger" :icon="Delete" size="default" plain>删除</el-button>
                            <el-button type="success" size="default" plain>设置分类</el-button>
                        </el-col>
                        <el-button type="primary" :icon="Refresh" size="default" />
                    </el-row>
                    <el-table ref="multipleTableRef" :data="tableData" style="width: 100%" height="calc(100% - 100px)" :header-cell-style="{ background: '#fafafa' }" @selection-change="handleSelectionChange">
                        <el-table-column type="selection" width="55" />
                        <el-table-column property="name" label="流程名称" width="200" />
                        <el-table-column property="flowKey" label="流程key" width="180" />
                        <el-table-column property="sort" label="分类" />
                        <el-table-column label="版本" width="180">
                            <template #default="scope">
                                <el-tag>{{ scope.row.version }}</el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column label="流程状态" width="180">
                            <template #default="scope">
                                <el-tag type="success">{{ scope.row.status }}</el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column property="updateTime" label="更新时间" />
                        <el-table-column fixed="right" label="操作" align="center" width="250">
                            <template #default="scope">
                                <el-button link type="primary" :icon="Edit" size="small" @click="editRecord(scope.$index, scope.row)" v-throttle>修改</el-button>
                                <el-button link type="success" size="small">发布</el-button>
                                <el-button link type="danger" :icon="Delete" size="small" @click="deleteRecord(scope.$index)">删除</el-button>
                            </template>
                        </el-table-column>
                    </el-table>
                    <div class="pageBtn">
                        <el-pagination v-model:currentPage="currentPage" v-model:page-size="pageSize" :page-sizes="[10, 15]" small="false" background layout="total, sizes, prev, pager, next, jumper" :total="100" @size-change="handleSizeChange" @current-change="handleCurrentChange" />
                    </div>
                </div>
            </div>
        </div>
        <el-dialog v-model="dialogAddRecord" title="审批流程编辑" @close="closeAdd">
            <el-form :model="addRecord" label-width="120px" ref="addRef" :rules="addRules">
                <el-form-item label="流程名称" prop="name">
                    <el-input v-model="addRecord.name" placeholder="流程名称" />
                </el-form-item>
                <el-form-item label="流程key" prop="flowKey">
                    <el-input v-model="addRecord.flowKey" placeholder="流程key"> </el-input>
                </el-form-item>
                <el-form-item label="分类" prop="sort">
                    <el-select v-model="addRecord.sort" placeholder="请选择">
                        <el-option label="临时用电" value="临时用电" />
                        <el-option label="设备检修" value="设备检修" />
                    </el-select>
                </el-form-item>
                <el-form-item label="版本" prop="version">
                    <el-input v-model="addRecord.version" placeholder="请选择工种"> </el-input>
                </el-form-item>
                <el-form-item label="状态" prop="status">
                    <el-select v-model="addRecord.status" placeholder="请选择">
                        <el-option label="已发布" value="已发布" />
                        <el-option label="未发布" value="未发布" />
                    </el-select>
                </el-form-item>
                <el-form-item>
                    <el-button type="warning" @click="dialogAddRecord = false" size="default" plain>取消</el-button>
                    <el-button type="primary" @click="confirmAddRecord(addRef)" size="default" v-throttle>确认</el-button>
                </el-form-item>
            </el-form>
        </el-dialog>
        <el-dialog v-model="deleteDialog" title="提示" width="30%" center @close="indexClear">
            <span>您确定要删除该条记录吗？</span>
            <template #footer>
                <span class="dialog-footer">
                    <el-button @click="deleteDialog = false" size="default">取消</el-button>
                    <el-button type="primary" @click="conFirmDelete" size="default" v-throttle>确认</el-button>
                </span>
            </template>
        </el-dialog>
    </div>
</template>

<script lang="ts" setup>
import { toRefs, reactive, defineComponent, ref } from 'vue';
import { storeToRefs } from 'pinia';
import { initBackEndControlRoutes } from '/@/router/backEnd';
import { useUserInfo } from '/@/stores/userInfo';
import { Session } from '/@/utils/storage';
import { Plus, Delete, Refresh, Edit } from '@element-plus/icons-vue';
import { ElTable, FormInstance, FormRules } from 'element-plus';
let global: any = {
    homeChartOne: null,
    homeChartTwo: null,
    homeCharThree: null,
    dispose: [null, '', undefined]
};

interface stateType {
    homeOne: Array<type>;
}
interface type {}
interface User {
    date: string;
    name: string;
    address: string;
}
const userInfo = useUserInfo();
const { userInfos } = storeToRefs(userInfo);
const state = reactive<stateType>({});
const multipleTableRef = ref<InstanceType<typeof ElTable>>();
const multipleSelection = ref<User[]>([]);
const handleSelectionChange = (val: User[]) => {
    multipleSelection.value = val;
};
const currentPage = ref(1);
const pageSize = ref(10);
const chosenIndex = ref(-1);
const handleSizeChange = (val: number) => {
    console.log(`${val} items per page`);
};
const handleCurrentChange = (val: number) => {
    console.log(`current page: ${val}`);
};
const tableData = reactive([
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    },
    {
        name: '风险点复评预警',
        flowKey: 'process111',
        sort: '未设置',
        version: 'V:4',
        status: '已发布',
        updateTime: '2021-04-22 15:21:31'
    }
]);

// 时间格式化
const timeForm = {
    hour12: false,
    year: 'numeric',
    month: '2-digit',
    day: '2-digit',
    hour: '2-digit',
    minute: '2-digit',
    second: '2-digit'
};
const addRef = ref<FormInstance>();
const addRules = reactive<FormRules>({
    name: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
    flowKey: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
    sort: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
    version: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
    status: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
    updateTime: [{ required: true, message: '该内容不能为空', trigger: 'blur' }]
});
const dialogDetails = ref(false);
const dialogAddRecord = ref(false);
const deleteDialog = ref(false);
const addRecord = ref({});
const details = ref({});

// 查看记录
const viewRecord = (row) => {
    details.value = JSON.parse(JSON.stringify(row));
    dialogDetails.value = true;
};

// 删除记录
const deleteRecord = (index) => {
    chosenIndex.value = index;
    deleteDialog.value = true;
};
const conFirmDelete = () => {
    tableData.splice(chosenIndex.value, 1);
    deleteDialog.value = false;
};

// 修改记录
const editRecord = (index, row) => {
    dialogAddRecord.value = true;
    chosenIndex.value = index;
    addRecord.value = JSON.parse(JSON.stringify(row));
};

// 新增修改记录确认
const confirmAddRecord = async (formEl: FormInstance | undefined) => {
    if (!formEl) return;
    await formEl.validate((valid, fields) => {
        if (valid) {
            if (chosenIndex.value == -1) {
                addRecord.value.updateTime = new Date().toLocaleString('zh', timeForm).replace(/\//g, '-');
                tableData.unshift(addRecord.value);
            } else {
                addRecord.value.updateTime = new Date().toLocaleString('zh', timeForm).replace(/\//g, '-');
                tableData[chosenIndex.value] = addRecord.value;
            }
            dialogAddRecord.value = false;
        } else {
            console.log('error submit!', fields);
        }
    });
};
const closeAdd = () => {
    addRecord.value = {};
    chosenIndex.value = -1;
};
const indexClear = () => {
    chosenIndex.value = -1;
};
// 折线图
const renderMenu = async (value: string) => {
    Session.set('projectId', value);
    userInfos.value.projectId = value;
    await initBackEndControlRoutes();
};
</script>

<style scoped lang="scss">
$homeNavLengh: 8;
.home-container {
    height: calc(100vh - 114px);
    box-sizing: border-box;
    overflow: hidden;
    .homeCard {
        width: 100%;
        padding: 20px;
        box-sizing: border-box;
        background: #fff;
        border-radius: 4px;

        .main-card {
            width: 100%;
            height: 100%;
            .cardTop {
                display: flex;
                align-items: center;
                justify-content: space-between;
                margin-bottom: 20px;
                .mainCardBtn {
                    margin: 0;
                }
            }
            .pageBtn {
                height: 60px;
                display: flex;
                align-items: center;
                justify-content: right;

                .demo-pagination-block + .demo-pagination-block {
                    margin-top: 10px;
                }
                .demo-pagination-block .demonstration {
                    margin-bottom: 16px;
                }
            }
        }
        &:last-of-type {
            height: calc(100% - 100px);
        }
    }
    .el-row {
        display: flex;
        align-items: center;
        margin-bottom: 20px;
        &:last-child {
            margin-bottom: 0;
        }
        .grid-content {
            align-items: center;
            min-height: 36px;
        }

        .topInfo {
            display: flex;
            align-items: center;
            font-size: 16px;
            font-weight: bold;

            & > div {
                white-space: nowrap;
                margin-right: 20px;
            }
        }
    }
}
</style>
